@@ -181,9 +181,10 @@ class Camera(BaseCamera):
                         if "gain" in capa:
                             gain = cc.get_gain()
                             gaindef = cc.getdef_gain()
-                        gamma = cc.get_gamma()
-                        gammadef = cc.getdef_gamma()
-                        print(f"i... EXPOAUTO == {expo_auto} vs def={expo_autodef};  gamma={gamma} vs {gammadef}")
+                        if "gamma" in capa:
+                            gamma = cc.get_gamma()
+                            gammadef = cc.getdef_gamma()
+                        print(f"i... EXPOAUTO == {expo_auto} vs def={expo_autodef}; ")
                     #--------------------------------------------------------------------------
 
 
@@ -221,8 +222,9 @@ class Camera(BaseCamera):
                         senh.setbox(f"expo {exposure_absolute}",  senh.expo)
                     if ("gain" in capa) and (gain!=gaindef): # gain is not frequently tunable
                         senh.setbox(f"g {gain}",  senh.gain)
-                    if (gamma!=gammadef): # manual
-                        senh.setbox(f"m {gamma}",  senh.gamma)
+                    if ("gamma" in capa):
+                        if (gamma!=gammadef): # manual
+                            senh.setbox(f"m {gamma}",  senh.gamma)
 
 
                     # ----  for detmo ---- work with detect motion--------------------
