@@ -22,7 +22,7 @@ import time
 from contextlib import contextmanager
 import signal
 
-from v4lc import V4L2_CTL, get_resolutions
+from flashcam.v4lc import V4L2_CTL, get_resolutions
 
 
 # print("v... unit 'unitname' loaded, version:",__version__)
