@@ -19,6 +19,7 @@ import json
 
 import itertools # duplicite list removeal
 
+import sys
 
 class V4L2_Control:
     """docstring for V4L2_CTL"""
@@ -188,7 +189,9 @@ class V4L2_CTL():
         #print("Executing: " + ' '.join(['v4l2-ctl', '-d', self.device, '-l']))
         CMD = ['which','v4l2-ctl']
         child = sp.Popen( CMD, stdout = sp.PIPE )
-        if child.returncode != 0:
+        returncode = child.returncode
+        print(f"i... v4l2-ctl:", returncode, 'str=',child.communicate()[0] )
+        if not(returncode is None):
             print("X... install v4l2-ctl:  apt install v4l-utils")
             sys.exit(1)
 
